    /* STM32 VL Discovery Library
     * LCD driver  LCD.c
     * 4 bit communication only
     * ver 2.0
     * Created on: Nov 7, 2012
     * Author: Prevzato a upraveno Novotny
     */
     
    /* Includes ------------------------------------------------------------------*/
#include "main.h"
#include "stm32f0xx_LCD.h"
#include "stm32f0xx_gpio.h"
#include "stm32f0xx_rcc.h"
#include "string.h"
#include "stm32f0xx_it.h"
#include "obsluha_rozhrani_HMI.h"
#include "stdio.h"

    /** Private_TypesDefinitions    */
     
    /** Private_Defines                     */
     
    /** Private_Macros                      */
     
    /** Private_Variables                   */

    /** Private_Functions                   */
void reverse(uint8_t s[]);
extern uint8_t LCD_text[];


    /**
      * @brief  LCD Init uvodni nastaveni do 4 bit modu
      * @param  None
      * @retval : None
      */
void LCD_Init(void)
{
			GPIO_ResetBits(GPIOB, LCD_RW);                                             //RW=0:Write mode
      GPIO_ResetBits(GPIOB, LCD_RS);                                             //RS=0:Instruction
      GPIO_ResetBits(GPIOB, LCD_E);                                              //E=0:Disable
      Delay(200);   // 200ms
         
      Posli4bitLCD(0x30);	//0b00100000  // display do 8-bitovem modu 
      Delay(5);
	
			Posli4bitLCD(0x30);	//0b00100000  // display je v 8-bitovem modu a prepneme ho do 4-bitoveho modu
      Delay(1);
			
			Posli4bitLCD(0x30);	//0b00100000  // display je v 8-bitovem modu a prepneme ho do 4-bitoveho modu
      Delay(1);
	
      Posli4bitLCD(0x20);	//0b00100000  // display je v 8-bitovem modu a prepneme ho do 4-bitoveho modu
      Delay(1);
			
      GPIO_ResetBits(GPIOB, LCD_E);                                      //E=0:Disable
      Delay(1);
      // format 0 0 1 DL N F - -
      // N = pocet radek 1=2 radky, 0=1 radka
      // DL = bitu komunikace 1=8bitu, 0=4bity
      // F = Font 1=5x10bodu, 0=5x8 bodu
      PosliPrikazLCD(0x28);	//0b00101000
      Delay(1);
			
			// prikaz 0 0 0 0 1 D C B
      // zapnuti D = displeje, C = kurzoru, B = blikani kurzoru
      PosliPrikazLCD(0x0C);	//0b00001111
      Delay(1);
			
			// posun kurzoru, inkrement adresy po zapisu
      PosliPrikazLCD(0x06);     //0b00000110               
			Delay(1);
			
			// reset displeje
      PosliPrikazLCD(0x01);     //0b00000110               
			Delay(1);
	}
     
/************************************* END OF INIT ********************************************/	
		
/**
	* @brief  Odesle 8-bit PRIKAZ do LCD
  * @param  : PRIKAZ nastaveni
  * @retval : None
 */
void PosliPrikazLCD(uint8_t cmd)        
		/* v promenne cmd mame zaslany typ prikazu byte,
		ten rozdelime a posleme po ctyrech bitech do LCD*/
{				
						GPIO_ResetBits(GPIOB, LCD_RS);  //nastavi RS=0:Instruction
            Posli4bitLCD(cmd);                                         
            cmd = cmd<<4;
            Posli4bitLCD(cmd);
}
		
/**
  * @brief  Odesle 8-bit DATA do LCD
  * @param  : DATA
  * @retval : None
 */
void PosliZnakLCD(uint8_t cmd)  //v promnn cmd mme poslany znak na LCD
{
            GPIO_SetBits(GPIOB, LCD_RS);    //nastavi RS=1:Data
            Posli4bitLCD(cmd);
            cmd = cmd<<4;
						Posli4bitLCD(cmd);
}
     
/**
  * @brief  Send 4-bit value to LCD
  * @param  command
  * @retval : None
 */
void Posli4bitLCD(uint8_t c)
{				
            uint16_t Pom;
            c=c>>4;
            Pom = GPIO_ReadOutputData(GPIOB);
            Pom = Pom & 0xFFF0;
            Pom = Pom | (uint16_t)c;
            GPIO_Write(GPIOB, Pom);
						Delay(1); // 20us
            GPIO_SetBits(GPIOB, LCD_E);				// E=1: Write enable 
						Delay(1);  // 20us
						GPIO_ResetBits(GPIOB, LCD_E); 		// E=0: Write disable	
}  
     
/**
  * @brief  Smaze LCD display
  * @param  : None
  * @retval : None
  */
void LCD_Clear(void)
{
        PosliPrikazLCD(0x01);	//0b00000001
            Delay(3); 				// zpozdeni 3ms
}
     
/**
  * @brief  Set LCD Cursor to Home
  * @param  None
  * @retval : None
  */
void LCD_CursorHome(void)
{
        PosliPrikazLCD(0x02);	//0b00000010
}
     
/**
  * @brief  Set LCD Cursor to position X,Y
  * @param  sloupec [0..15], radka [0,1,2,3]
  * @retval : None
 */
void set_cursor (int sloupec, int radka)
{ // 0x80: bude se nastavovat adresa v DDRAM
			// 0x40: adresa prvni pozice vlevo druheho radku 
      PosliPrikazLCD(0x80 |((radka * 0x40) + sloupec));
}
        
/**
  * @brief  String variable print to LCD
  * @param  string pointer
  * @retval : None
 */   
void printLCD(uint8_t *retezec)         //posila se odkaz na retezec
{
            uint8_t i=0;
            // kontrola pointeru zda na neco ukazuje
            if (!retezec) return;
            while(retezec[i]!='\0')
            {
                    PosliZnakLCD(retezec[i]);
                    i++;
            }
}

/**
 * @brief  String constant print to LCD
 * @param  string pointer
 * @retval : None
*/
void printLCDc(const uint8_t *retezec)  //posila se odkaz na retezec z flash 
{ // nebo void printLCDc(const char *retezec)
            uint8_t i=0;
            // pro sichr si zkontrolujeme pointer
            if (!retezec) return;
            while(retezec[i]!='\0')
            {
                    PosliZnakLCD(retezec[i]);
                    i++;
            }
}

/**
  * @brief  Convert integer to ASCII caracters
  * @param  number for convert, string area
  * @retval : None
 */
void itoa(int16_t n, uint8_t s[])
{  
	 uint8_t minus;
	 uint8_t i;
	
    if(n<0)   						// zaporne cislo
		{
			minus=1;
			n=-n;					     	// prida minus znamenko
		}	
		else minus=0; // kladne cislo		
			
    for( i = 0;i<5;i++) {       
        s[i] = n % 10 + '0';   // dava zbytek po deleni + nulu ascii hex format
			n /= 10;
    }     										 // odstrani se nejnizsi dekada a priradi do 'n' 
    if(minus)  //prida znamenko
		{
			s[i]='-';
		}
		else
		{
			s[i]='+';  
		}
		s[i+1] = '\0';  //prida ukoncovaci znak
    reverse(s);			
}

/**
  * @brief  Reverse string area
  * @param  s = string
  * @retval : None
  */
void reverse(uint8_t s[])
{
    int i, j;
    char c;
 
    for (i = 0, j = strlen(s)-1; i<j; i++, j--) 
	 {
        c = s[i];
        s[i] = s[j];
        s[j] = c;
    }
}


