/**
  ******************************************************************************
  * @file    SysTick/stm32f0xx_it.c 
  * @author  MCD Application Team
  * @version V1.0.0
  * @date    23-March-2012
  * @brief   Main Interrupt Service Routines.
  *          This file provides template for all exceptions handler and 
  *          peripherals interrupt service routine.
  ******************************************************************************
  * @attention
  *
  * <h2><center>&copy; COPYRIGHT 2012 STMicroelectronics</center></h2>
  *
  * Licensed under MCD-ST Liberty SW License Agreement V2, (the "License");
  * You may not use this file except in compliance with the License.
  * You may obtain a copy of the License at:
  *
  *        http://www.st.com/software_license_agreement_liberty_v2
  *
  * Unless required by applicable law or agreed to in writing, software 
  * distributed under the License is distributed on an "AS IS" BASIS, 
  * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  * See the License for the specific language governing permissions and
  * limitations under the License.
  *
  ******************************************************************************
  */ 

/* Includes ------------------------------------------------------------------*/
#include "stm32f0xx_it.h"
#include "stm32f0xx_LCD.h"
#include "stm32f0xx_rcc.h"
#include "stm32f0xx_gpio.h"
#include "stm32f0xx_tim.h"
#include "obsluha_rozhrani_HMI.h"
#include "main.h"
#include "stm32f0xx_voltmetr.h"

/** @addtogroup STM32F0_Discovery_Peripheral_Examples
  * @{
  */

/** @addtogroup SysTick_Example
  * @{
  */ 

/* Private typedef -----------------------------------------------------------*/
/* Private define ------------------------------------------------------------*/
/* Private macro -------------------------------------------------------------*/
/* Global variables ---------------------------------------------------------*/
extern int16_t max_hodn;        //udrzuji vysledky vypoctenych hodnot
extern int16_t min_hodn;
extern int16_t posl_max;
extern int16_t posl_min;
extern uint8_t odber_bezi;  // infomace o probihajicim mereni pro zobrazeni na displeji
extern int16_t storage[POCET_VZORKU];
uint16_t posun_nuly=ROZL_ADC/2;   // polovina z rozsahu AD prevodniku 12bit 4096, protoze napeti je posunuto do poloviny rozsahu tj ~1,5V


/* Private variables ---------------------------------------------------------*/
uint16_t pocet_odberu=0;			// pocet odberu do posunuti ukazatele na zacatek pole(kruhovy zasobnik)		
uint16_t pocet_dat_refresh_LCD=0;	// pocet odberu do obnoveni udaje LCD displeje
	
uint8_t refr_udaj_display; 		// pozadavek na prekresleni hodnoty na displeji
int16_t ADC_akt_hodnota;			// aktualni hodnota ADC
int16_t *ukazatel;            // ukazatel do pole s daty 


/* Private function prototypes -----------------------------------------------*/
/* Private functions ---------------------------------------------------------*/

/******************************************************************************/
/*            Cortex-M0 Processor Exceptions Handlers                         */
/******************************************************************************/

/**
  * @brief  This function handles NMI exception.
  * @param  None
  * @retval None
  */
void NMI_Handler(void)
{
}

/**
  * @brief  This function handles Hard Fault exception.
  * @param  None
  * @retval None
  */
void HardFault_Handler(void)
{
  /* Go to infinite loop when Hard Fault exception occurs */
  while (1)
  {
  }
}

/**
  * @brief  This function handles SVCall exception.
  * @param  None
  * @retval None
  */
void SVC_Handler(void)
{
}

/**
  * @brief  This function handles PendSVC exception.
  * @param  None
  * @retval None
  */
void PendSV_Handler(void)
{
}

/**
  * @brief  This function handles SysTick Handler.
  * @param  None
  * @retval None
  */

/******************************************************************************/
/*                 STM32F0xx Peripherals Interrupt Handlers                   */
/*  Add here the Interrupt Handler for the used peripheral(s) (PPP), for the  */
/*  available peripheral interrupt handler's name please refer to the startup */
/*  file (startup_stm32f0xx.s).                                            */
/******************************************************************************/

/**
  * @brief  Obsluha externiho preruseni od SYSTICK
  * @param  : None
  * @retval : None
  */
void SysTick_Handler(void)
{
 TimingDelay_Decrement(); //pouzito pro zpozdeni
}

/**
  * @brief  Obsluha externiho preruseni od tlacitka PA0
  * @param  : None
  * @retval : Nastavena faze a tvar signalu.
  */
void EXTI0_1_IRQHandler(void)
{ 
}

/**
  * @brief   Obsluha preruseni TIM2, zpracovani odberu vzorku z ADC
  * @param  : None
  * @retval : Ziskany vzorek hodnota z ADC
	* @note 	: Po kazdem odberu se provadi vypocet aktualizace vsech hodnot
  */
void TIM2_IRQHandler (void)
{ // if ((TIM2->SR & 0x0001) != 0)// check interrupt source 
  // {	
	TIM2->SR &= ~0x3;    						// smazani preruseni 	
	odber_bezi=1;  
	GPIOC->ODR|=0x100;							//rozsvitit LED PC8/
	
	ADC_akt_hodnota=ADC1_Read()-posun_nuly;   	// odecet hodnoty z ADC prevodniku, korekce posunu nuly doprostred rozsahu
	
	// pocitani hodnot napeti
	najdi_max_hodn(ADC_akt_hodnota);
	najdi_min_hodn(ADC_akt_hodnota);
	vypocti_stredni_elektrolyt_hodn(ADC_akt_hodnota,ukazatel);  // provede aktualizaci vysledku s novym odberem
	vypocti_stredni_aritm_hodn(ADC_akt_hodnota,ukazatel); 			// provede aktualizaci vysledku s novym odberem
	vypocti_efektivni_hodn(ADC_akt_hodnota,ukazatel); 					// provede aktualizaci vysledku s novym odberem
	
	pocet_odberu++;  						// inkrementace poctu odberu vzorku
	pocet_dat_refresh_LCD++;  	// inkrementace poctu odberu vzorku 
	*ukazatel=ADC_akt_hodnota;  //zapis odeten	hodnoty do kruhoveho zasobniku 
	ukazatel++;  								//inkrementace ukazatele do oblasti s daty
	
	if(pocet_odberu>=POCET_VZORKU) // pocet odberu do posunuti ukazatele na zacatek pole(kruhovy zasobnik)		
		{
			ukazatel=storage;   		// posun ukazatele na pocatecni hodnotu
			pocet_odberu=0;	
		}
		if(pocet_dat_refresh_LCD>=REFRESH_DISPLAY)
		{						
			posl_max=max_hodn;			// zapis hodnoty do promenne vyhodnocuje se jednou za periodu zobrazeni
			posl_min=min_hodn;	  	// zapis hodnoty do promenne vyhodnocuje se jednou za periodu zobrazeni
			max_hodn=-posun_nuly; 	// pocatecni nastaveni hodnoty
			min_hodn=posun_nuly;		// pocatecni nastaveni hodnoty
			refr_udaj_display=1;  	// vydani pozadavku na aktualizaci displeje 
			pocet_dat_refresh_LCD=0;	
		}							
	GPIOC->ODR&=~0x100; 						//zhasnout LED PC8 
	odber_bezi=0; 									// nahozeni bitu probiha odber vzorku 
}
/**
  * @brief  This function handles PPP interrupt request.
  * @param  None
  * @retval None
  */
/*void PPP_IRQHandler(void)
{
}*/

/**
  * @}
  */ 

/**
  * @}
  */ 

/************************ (C) COPYRIGHT STMicroelectronics *****END OF FILE****/
