/*
*	Voltmetr
* Program byl napsan pro mikrokontroler ARM Cortex STM32F051R8
* Meri hodnoty maximalni, minimalni, stredni elektrolyticka, stredni aritmeticka, efektivni
*	Vstup signlu ADC prevodniku na pin PC4
* Prepinani zobrazovane hodnoty pomoci tlacitka pin PA0 proti GND.
* Zobrazovani LCD displejem 2x16znaku pripojeni na port B, definice pinu v souboru "stm32f0xx_LCD.h"
* Autor: Pavel Novotn
*	Date:  04/2013
* Licence: freeware
*/


#include "system_stm32f0xx.h"
#include "stm32f0xx_my_config.h"
#include "stm32f0xx_gpio.h"
#include "stm32f0xx_rcc.h"
#include "core_cm0.h"
#include "stm32f0xx_LCD.h"
#include "obsluha_rozhrani_HMI.h"
#include "main.h"
#include "stdint.h"
#include "stm32f0xx_voltmetr.h"

/* Types define----------------------------------------------------------------*/

/* Private variables ---------------------------------------------------------*/
uint32_t ADC_value;  								//promenna ulozeni hodnoty ADC
static __IO uint32_t TimingDelay;		//pro zpozdeni pocita preruseni realizovane SYSTICK

extern uint8_t poz_hodnota;
enum {MAX,MIN,ELEKTROLYT,ARITM,EFEKT}typy_hodnot; 

// promene pro merene hodnoty
extern int16_t posl_max;
extern int16_t posl_min;
extern int16_t elektrol_hodn;
extern int16_t aritm_hodn;
extern int16_t efektiv_hodn;

extern uint8_t refr_udaj_display;  	// pozadavek na prekresleni hodnoty na displej
extern int16_t *ukazatel; 					// promena ukazatele do oblasti nactenych pulsu

extern uint8_t odber_bezi;  				// probiha odber vzorku
int16_t storage[POCET_VZORKU];			// definice a alokace pole uloziste vzorku


/* funkcni prototypy-----------------------------------------------------------*/

/**
  * @brief  Nastaveni periferi, 
  * @param  None
  * @retval None
	* @note 	Hlavni smycka DDS generatoru, testuje se v ni pouze tlacitko
  */
int main (void)
{ 
	NVIC_my_config();		 				// volani nastaveni preruseni	
	GPIO_my_config();						// volani nastaveni periferie obecnych vstupu vystupu
	SYSTICK_my_config(); 				// volani nastaveni periferie SYSTICK
	USART_my_config(); 					// volani nastaveni periferie USART
	ADC_my_config();
	TIMER_my_config();
	LCD_my_config();						// volani funkce inicializujici display
	
	ukazatel=storage;       		// pocatecni nastaveni ukazatele prvni adresu dat
	display_start_text();       // text pocatecniho nastaveni
	spust_odbery();							// start odberu vzorku
	
	/************************************************************************************************************************/
	/**********************************************  HLAVNI SMYCKA   ********************************************************/
	/************************************************************************************************************************/
	while(1)
	{	// test na stisk tlacitka
		if(!(GPIO_ReadInputDataBit(GPIOA, GPIO_Pin_0)))
		{ 
			zmen_zobrazeni();				//zmeni druh zobrazovane merene hodnoty 
		}
		if(refr_udaj_display)
		{
			GPIOC->ODR|=0x200;			//rozsvitit LED PC9/
			zobraz_data();					//aktualizuj data zobrazena na displeji
			GPIOC->ODR&=~0x200; 		//zhasnout 	LED PC9/
		}
	}
} // end of main()

/**
  * @brief  Zobrazi data na display podle vyberu 
  * @param  None
  * @retval None
	* @note 	
  */
void zobraz_data()
{
	switch(poz_hodnota)
			{
				case(MAX):zobraz_data_signal(uprav_meritko((double)posl_max));break;
				case(MIN):zobraz_data_signal(uprav_meritko((double)posl_min));break;
				case(ELEKTROLYT):zobraz_data_signal(elektrol_hodn);break;
				case(ARITM):zobraz_data_signal(aritm_hodn);break;
				case(EFEKT):zobraz_data_signal(efektiv_hodn);break;
			}
			refr_udaj_display=0;  // bit display byl aktualizovan 
}

/**
  * @brief  Realizuje zpozdeni, kvantum je dane SYSTICK nastavene na 1ms
  * @param  : nTime hodnota pozadovaneho zpozdeni 
  * @retval : none
  */
void Delay(__IO uint32_t nTime)
{ 
  TimingDelay = nTime;
  while(TimingDelay != 0);   
}

void TimingDelay_Decrement(void)  // volana periodicky z obsluhy preruseni systick generuje delay pulsy
{	
  if (TimingDelay != 0x00)
  { 
    TimingDelay--;
  }
}

 
