/**
  ******************************************************************************
  * @file    SysTick/stm32f0xx_it.c 
  * @author  MCD Application Team
  * @version V1.0.0
  * @date    23-March-2012
  * @brief   Main Interrupt Service Routines.
  *          This file provides template for all exceptions handler and 
  *          peripherals interrupt service routine.
  ******************************************************************************
  * @attention
  *
  * <h2><center>&copy; COPYRIGHT 2012 STMicroelectronics</center></h2>
  *
  * Licensed under MCD-ST Liberty SW License Agreement V2, (the "License");
  * You may not use this file except in compliance with the License.
  * You may obtain a copy of the License at:
  *
  *        http://www.st.com/software_license_agreement_liberty_v2
  *
  * Unless required by applicable law or agreed to in writing, software 
  * distributed under the License is distributed on an "AS IS" BASIS, 
  * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  * See the License for the specific language governing permissions and
  * limitations under the License.
  *
  ******************************************************************************
  */ 

/* Includes ------------------------------------------------------------------*/
#include "stm32f0xx_it.h"
#include "stm32f0xx_LCD.h"
#include "stm32f0xx_rcc.h"
#include "stm32f0xx_gpio.h"
#include "stm32f0xx_tim.h"
#include "obsluha_rozhrani_HMI.h"
#include "main.h"


/* Private typedef -----------------------------------------------------------*/
/* Private define ------------------------------------------------------------*/
/* Private macro -------------------------------------------------------------*/
/* Global variables ---------------------------------------------------------*/
uint8_t refr_udaj_display;        //pozadavek na refresh dat display
extern float perioda;
extern float frekvence;

/* Private variables ---------------------------------------------------------*/
uint16_t pocet_dat_refresh_LCD=0;	// pocet odberu do obnoveni udaje LCD displeje
uint32_t ccr1;	// zaznam  registru TIM2->CCR1

/* Private function prototypes -----------------------------------------------*/
/* Private functions ---------------------------------------------------------*/

/******************************************************************************/
/*            Cortex-M0 Processor Exceptions Handlers                         */
/******************************************************************************/

/**
  * @brief  This function handles NMI exception.
  * @param  None
  * @retval None
  */
void NMI_Handler(void)
{
}

/**
  * @brief  This function handles Hard Fault exception.
  * @param  None
  * @retval None
  */
void HardFault_Handler(void)
{
  /* Go to infinite loop when Hard Fault exception occurs */
  while (1)
  {
  }
}

/**
  * @brief  This function handles SVCall exception.
  * @param  None
  * @retval None
  */
void SVC_Handler(void)
{
}

/**
  * @brief  This function handles PendSVC exception.
  * @param  None
  * @retval None
  */
void PendSV_Handler(void)
{
}

/**
  * @brief  This function handles SysTick Handler.
  * @param  None
  * @retval None
  */

/******************************************************************************/
/*                 STM32F0xx Peripherals Interrupt Handlers                   */
/*  Add here the Interrupt Handler for the used peripheral(s) (PPP), for the  */
/*  available peripheral interrupt handler's name please refer to the startup */
/*  file (startup_stm32f0xx.s).                                            */
/******************************************************************************/

/**
  * @brief  Obsluha externiho preruseni od SYSTICK
  * @param  : None
  * @retval : None
  */
void SysTick_Handler(void)
{
 TimingDelay_Decrement(); //pouzito pro dekrementaci hodnoty zpozdeni
}

/**
  * @brief  
  * @param  : None
  * @retval :
  */
void EXTI0_1_IRQHandler(void)
{ 
}

/**
  * @brief   Obsluha preruseni od Timer1, hradluje TIM2
  * @param  : None
  * @retval : prime mereni frekvence, vypocet prumerne periody
  */
void TIM1_BRK_UP_TRG_COM_IRQHandler()
{ 	
	if(TIM1->SR&0x01==0x01)  // preruseni od update event
	{
		ccr1=(TIM2->CNT);		// presun hodnoty do promenne potom se pocita uz jen s ccr1 nemeni se
		perioda=1.0/ccr1;
		frekvence=ccr1;
		refr_udaj_display=1;	// pozadavek na refresh displeje
		TIM1->EGR|= 0x1; 		  //update generation, znovunastaveni citace
		TIM2->EGR|= 0x1; 		  //update generation, znovunastaveni citace
		TIM1->SR &= ~0x1;    	// smazani preruseni update interrupt event
		TIM1->CR1|=0x01;	 	 	//counter enable novy odmer
	}
}

/**
  * @brief   Obsluha preruseni od Timer2
  * @param  : None
  * @retval : 
  */
void TIM2_IRQHandler (void)
{ 
}
/**
  * @brief  This function handles PPP interrupt request.
  * @param  None
  * @retval None
  */
/*void PPP_IRQHandler(void)
{
}*/

/**
  * @}
  */ 

/**
  * @}
  */ 

/************************ (C) COPYRIGHT STMicroelectronics *****END OF FILE****/
