/*Konfigurace periferi STM32F051*/


#include "stm32f0xx_my_config.h"
#include "stm32f0xx_gpio.h"
#include "stm32f0xx_rcc.h"
#include "stm32f0xx_LCD.h"
#include "main.h"


GPIO_InitTypeDef GPIO_InitStructure;
RCC_ClocksTypeDef RCC_Clocks;


/********************************* GPIO **************************************/
/**
  * @brief  Inicializace vstunu a vystupu MCU
  * @param  : None
  * @retval : Nastaveni GPIO
  */
void GPIO_my_config(void)
 {   
  /* GPIOx Periph clock enable */
	RCC_AHBPeriphClockCmd(RCC_AHBPeriph_GPIOA, ENABLE);
  RCC_AHBPeriphClockCmd(RCC_AHBPeriph_GPIOC, ENABLE);
	 
 // Configure PC8,9 as output pushpull mode     LED diody
  GPIO_InitStructure.GPIO_Pin = GPIO_Pin_8|GPIO_Pin_9;
  GPIO_InitStructure.GPIO_Mode = GPIO_Mode_OUT;
  GPIO_InitStructure.GPIO_OType = GPIO_OType_PP;
  GPIO_InitStructure.GPIO_Speed = GPIO_Speed_50MHz;
  GPIO_InitStructure.GPIO_PuPd = GPIO_PuPd_NOPULL;
  GPIO_Init(GPIOC, &GPIO_InitStructure);
	 
	  // Configure PA0 as input   ovladaci tlacitka
  GPIO_InitStructure.GPIO_Pin = GPIO_Pin_0;
  GPIO_InitStructure.GPIO_Mode = GPIO_Mode_IN;
  GPIO_InitStructure.GPIO_OType = GPIO_OType_OD;
  GPIO_InitStructure.GPIO_Speed = GPIO_Speed_50MHz;
  GPIO_InitStructure.GPIO_PuPd = GPIO_PuPd_UP;
  GPIO_Init(GPIOA, &GPIO_InitStructure);
} 
 
/***************************************** LCD display *****************************************/
 /**
  * @brief  Inicializace LCD displeje
  * @param  : None
  * @retval : Nastaveni GPIO pro dicplej
  */
void LCD_my_config(void) 
 {
			RCC_AHBPeriphClockCmd(RCC_AHBPeriph_GPIOB, ENABLE);
	 /* Configure the GPIO Pins for LCD.*/
     
      GPIO_InitStructure.GPIO_Pin = LCD_E |LCD_RW | LCD_RS | LCD_D4 | LCD_D5
                      | LCD_D6 | LCD_D7 ;  
			GPIO_InitStructure.GPIO_Mode = GPIO_Mode_OUT;
      GPIO_InitStructure.GPIO_OType = GPIO_OType_PP;
      GPIO_InitStructure.GPIO_Speed = GPIO_Speed_50MHz;
      GPIO_Init(GPIOB, &GPIO_InitStructure);
			LCD_Init();   // inicializace display 4 bit komunikace
 }

/**************************************** SYSTICK *******************************************/
/**
  * @brief  Inicializace SYSTICK
  * @param  : None
  * @retval : None
  */
void SYSTICK_my_config() 
{	 /* SysTick end of count event each 1ms */
  RCC_GetClocksFreq(&RCC_Clocks);
  SysTick_Config(RCC_Clocks.HCLK_Frequency / 1000);  //vyrabi preruseni po 1 ms 
}

/*************************************** NVIC *******************************************/
/**
  * @brief  Nastaveni priorit NVIC, nizsi cislo = vyssi priorita
  * @param  : None
  * @retval : None
  */
void NVIC_my_config()	 //nested vector interrupt 
{	
	/* specifikace line prichoziho preruseni line 1 a 0, stanoveni jeho priority(0 az 3) */ 
  NVIC_SetPriority(SysTick_IRQn,10); // set priority for systick pouziva se pro LCD
	NVIC_SetPriority(TIM1_BRK_UP_TRG_COM_IRQn ,3);
	
	/* Enable the Systick interrupt*/
	NVIC_EnableIRQ(SysTick_IRQn );  // for delay generate
	NVIC_EnableIRQ(TIM1_BRK_UP_TRG_COM_IRQn ); // handler se musi jmenovat stejne 
}
	
