/**********************************************************************************************************************
*	Mereni frekvence prmou metodou, vypocet delky periody
*
* Program byl napsan pro mikrokontroler ARM CortexM0 STM32F051R8 zabudovany ve vyvojovem kitu STM32F0-Discovery
*	Vstup citace TIM2 je na pinu PA5.TIM2 je hradlovan casovacem TIM1 po dobu 1 sec
* Je mozne pouzit take jine prubehy nez obdelnik, potom
* musi jit signal pres vnitrni komparator COMP1. Vstup komparatoru PA1, vystup PA6. Propojeni se
* vstupem casovace dratovou propojkou.
* Nastavovani zobrazeni pomoci tlacitka na pinu PA0 spina proti GND.
* Zobrazovani LCD displejem 2x16znaku pripojeni na port B, definice pinu v souboru "stm32f0xx_LCD.h"
*
* Autor: Pavel Novotn
*	Date:  04/2013
* Licence: freeware
************************************************************************************************************************/


#include "system_stm32f0xx.h"
#include "stm32f0xx_my_config.h"
#include "stm32f0xx_gpio.h"
#include "stm32f0xx_rcc.h"
#include "core_cm0.h"
#include "stm32f0xx_LCD.h"
#include "frekvence.h"
#include "obsluha_rozhrani_HMI.h"
#include "main.h"
#include "stdint.h"


/* Types define----------------------------------------------------------------*/

/* Private variables ---------------------------------------------------------*/
static __IO uint32_t TimingDelay;		//pro zpozdeni pocita preruseni realizovane SYSTICK

extern uint8_t poz_hodnota;
enum {FREQ,PERIOD}typy_hodnot; 

extern uint8_t refr_udaj_display;  // pozadavek na prekresleni hodnotz na displeji

extern float frekvence;
extern float perioda;

/* funkcni prototypy-----------------------------------------------------------*/

/**
  * @brief  Nastaveni periferi, hlavni smycka 
  * @param  None
  * @retval None
  */
int main (void)
{ 
	NVIC_my_config();		 				// volani nastaveni preruseni	
	GPIO_my_config();						// Konfiguruje PA0,1,2 jako vstupy pro ovladaci tlacitka, PC8,9 jako vystupy pro LED na vyvojovem kitu
	SYSTICK_my_config(); 				// volani nastaveni periferie SYSTICK
	frequencySetTIM1_TIM2();		// konfigurace TIM2 pro mereni frekvence
	LCD_my_config();						// volani funkce inicializujici display
	
	display_start_text();       // text pocatecniho nastaveni
	
	/************************************************************************************************************************/
	/**********************************************  HLAVNI SMYCKA   ********************************************************/
	/************************************************************************************************************************/
	while(1)
	{	// test na stisk tlacitka
		if(!(GPIO_ReadInputDataBit(GPIOA, GPIO_Pin_0)))
		{ 
			zmen_zobrazeni();				// zmeni druh zobrazovane hodnoty 
		}
		if(refr_udaj_display)
		{
			GPIOC->ODR|=0x200;			//rozsvitit LED PC9/
			zobraz_data();					// aktualizuj data na displeji
			GPIOC->ODR&=~0x200; 		//zhasnout LED PC9/
		}
	}
} // end of main()

/**
  * @brief  Zobrazeni aktualizovanych dat v zavislosti na volbe zobrazeni
  * @param  None
  * @retval None
  */
void zobraz_data()
{
	switch(poz_hodnota)
			{
				case(FREQ):zobraz_data_signal(frekvence,0);break;    					//zobrazi (text,pocet desetinych mist)
				case(PERIOD):zobraz_data_signal(perioda*1000000000,6);break;
			}
			refr_udaj_display=0;  // bit display byl aktualizovan 
}

/**
  * @brief  Realizuje zpozdeni, kvantum je dane SYSTICK nastavene na 1ms
  * @param  : nTime hodnota casu pozadovaneho zpozdeni 
  * @retval : none
  */
void Delay(__IO uint32_t nTime)
{ 
  TimingDelay = nTime;
  while(TimingDelay != 0);   
}

void TimingDelay_Decrement(void)  // volana periodicky z obsluhy preruseni systick generuje delay pulsy
{	
  if (TimingDelay != 0x00)
  { 
    TimingDelay--;
  }
}

 
