#include "frekvence.h"
#include "stm32f0xx_gpio.h"
#include "stm32f0xx_rcc.h"
#include "stm32f0xx.h"
#include "stm32f0xx_my_config.h"

float perioda=0.0;
float frekvence=0.0;
float delka_kladna=0.0;
float delka_zaporna=0.0;
float strida=0.0;


/**
  * @brief Nastaveni TIM2 pro neprime mereni frekvence, periody, stridy
  * @param  : None
  * @retval : None
  */
void frequencySetTIM2() 
{	
	RCC_AHBPeriphClockCmd(RCC_AHBPeriph_GPIOA, ENABLE); 		// povoleni hodin do periferie IO
	RCC_APB1PeriphClockCmd(RCC_APB1Periph_TIM2, ENABLE);		// povoleni hodin do periferie TIM2
	RCC_APB2PeriphClockCmd(RCC_APB2Periph_SYSCFG, ENABLE);	// povoleni hodin do periferie COMP hodiny jsou spolecne s SYSCFG

	GPIOA->OSPEEDR|=0x000C;  		//PA1 50MHz
	GPIOA->OSPEEDR|=0x0C00;  		//PA5 50MHz
	GPIOA->OSPEEDR|=0x3000;  		//PA6 50MHz
	
	GPIOA->MODER|=0x800;	      //AF function pro vstup PA5	
	GPIOA->AFR[0]|=0x200000;	  //AFRL nastaveni PA5 na AF2(TIM2_CH1_ETR)

	GPIOA->MODER|=0x2000;	      //AF function pro vstup PA6
	GPIOA->AFR[0]|=0x7000000;	  //AFRL nastaveni PA6 na AF7(COMP1_OUT)

	// komparator nastaveni pro vstup signalu
	COMP->CSR|=0x3000;  				//COMP1HYST=11(high) Comparator 1 hysteresis
	COMP->CSR|=0x500;  	 				//COMP1OUTSEL=101: Timer 2 OCrefclear input: Comparator 1 output selection
	COMP->CSR|=0x030;	 					//COMP1INSEL=011: comp level is Vrefint 1,2V: Comparator 1 inverting input selection
	COMP->CSR|=0x0;	 						//COMP1MODE=00: High speed / full power: Comparator 1 mode
	COMP->CSR|=0x1;	 						//COMP1EN: Comparator 1 enable
	
	// nastaveni TIM2 pro mereni delky periody zachyt CCR1
	TIM2->PSC=0; 								//sampling frequency (48MHz PSC=0+1) (1MHz PSC=47+1) 
	TIM2->CCMR1|=0x01; 					//CC1 chanel is configured as input, IC1 is mapped on TI1
	TIM2->CCER=0x00;	 					//sensitive to rising edge
	TIM2->CCMR1|=0x00; 					//IC1PS prescaler each edge capture
	TIM2->CCER=0x01;	 					//CC1E=1 capture enabled
	TIM2->SMCR|=0x50;						//TS TRIGGER select TI1FP1
	TIM2->SMCR|=0x04;	 					//SMS Reset mode
	TIM2->CR1|=0x01;	 					//counter enable
	
	// nastaveni TIM2 pro mereni stridy zachyt CCR2
	TIM2->CCMR1|=0x200; 				//CC2 input IC2 namapovan na TI1
	TIM2->CCER|=0x20;	 					//CC2P=1 active on falling edge
	TIM2->CCER|=0x10;	 					//CC2E=1 capture enabled	
}

