/*Konfigurace periferi STM32F051*/


#include "stm32f0xx_my_config.h"
#include "stm32f0xx_gpio.h"
#include "stm32f0xx_rcc.h"
#include "stm32f0xx_LCD.h"
#include "main.h"


GPIO_InitTypeDef GPIO_InitStructure;
RCC_ClocksTypeDef RCC_Clocks;


/********************************* GPIO **************************************/
/**
  * @brief  Inicializace vstunu a vystupu MCU
  * @param  : None
  * @retval : Nastaveni GPIO
  */
void GPIO_my_config(void)
 {   
  /* GPIOx Periph clock enable */
	RCC_AHBPeriphClockCmd(RCC_AHBPeriph_GPIOA, ENABLE);
  RCC_AHBPeriphClockCmd(RCC_AHBPeriph_GPIOC, ENABLE);
	 
 // Configure PC8,9 as output pushpull mode     LED diody
  GPIO_InitStructure.GPIO_Pin = GPIO_Pin_8|GPIO_Pin_9;
  GPIO_InitStructure.GPIO_Mode = GPIO_Mode_OUT;
  GPIO_InitStructure.GPIO_OType = GPIO_OType_PP;
  GPIO_InitStructure.GPIO_Speed = GPIO_Speed_50MHz;
  GPIO_InitStructure.GPIO_PuPd = GPIO_PuPd_NOPULL;
  GPIO_Init(GPIOC, &GPIO_InitStructure);
	 
	  // Configure PA0 as input   ovladaci tlacitka
  GPIO_InitStructure.GPIO_Pin = GPIO_Pin_0;
  GPIO_InitStructure.GPIO_Mode = GPIO_Mode_IN;
  GPIO_InitStructure.GPIO_OType = GPIO_OType_OD;
  GPIO_InitStructure.GPIO_Speed = GPIO_Speed_50MHz;
  GPIO_InitStructure.GPIO_PuPd = GPIO_PuPd_UP;
  GPIO_Init(GPIOA, &GPIO_InitStructure);
} 
 
/***************************************** LCD display *****************************************/
 /**
  * @brief  Inicializace LCD displeje
  * @param  : None
  * @retval : Nastaveni GPIO pro dicplej
  */
void LCD_my_config(void) 
 {
			RCC_AHBPeriphClockCmd(RCC_AHBPeriph_GPIOB, ENABLE);
	 /* Configure the GPIO Pins for LCD.*/
     
      GPIO_InitStructure.GPIO_Pin = LCD_E |LCD_RW | LCD_RS | LCD_D4 | LCD_D5
                      | LCD_D6 | LCD_D7 ;  
			GPIO_InitStructure.GPIO_Mode = GPIO_Mode_OUT;
      GPIO_InitStructure.GPIO_OType = GPIO_OType_PP;
      GPIO_InitStructure.GPIO_Speed = GPIO_Speed_50MHz;
      GPIO_Init(GPIOB, &GPIO_InitStructure);
			LCD_Init();   // inicializace display 4 bit komunikace
 }
 
/**************************************** TIMER *******************************************/
 /**
  * @brief  Inicializace TIM2 32bitu
  * @param  : None
  * @retval : 
  */
void TIMER_my_config()
{	
	RCC_APB1PeriphClockCmd(RCC_APB1Periph_TIM2, ENABLE);
	  /* Compute the prescaler value */
  //PrescalerValue = (uint16_t) (SystemCoreClock  / 6000000) - 1;

  /* Time base configuration */
  TIM2->CR1|=0x80;  // ARPE enable autoreload register
	TIM2->PSC=47;				//nastaven clk pro tim2 na T=1us
	TIM2->ARR=199; 			// fill autoreload register vel.32bit  1000=1ms  cislo+1us =vysledny cas us 0.1s
  TIM2->CR1|=0x10;  	// DIR=0 upcount
//	TIM2->CR1|=0x4;  		// URS overflow/underflow or DMA request generate interrupt
	TIM2->CR2|=0x020;		// UG update generate TRG0 output for trigger ADC
	TIM2->DIER|=0x1;  		//UIE update interrupt enable
}

/**************************************** SYSTICK *******************************************/
/**
  * @brief  Inicializace SYSTICK
  * @param  : None
  * @retval : None
  */
void SYSTICK_my_config() 
{	 /* SysTick end of count event each 1ms */
  RCC_GetClocksFreq(&RCC_Clocks);
 	SysTick->LOAD=0xBB7F;  // BB7F=47999  tj. deleni kmitoctu MCU (47999 + 1) tzn. bude provadena 1ms perioda preruseni
	SysTick->VAL=0;
	SysTick->CTRL=0x7;      // enable, source clock MCU , downcount
}

/*************************************** NVIC *******************************************/
/**
  * @brief  Nastaveni priorit NVIC, nizsi cislo = vyssi priorita
  * @param  : None
  * @retval : None
  */
void NVIC_my_config()	 //nested vector interrupt 
{	
	/* specifikace line prichoziho preruseni line 1 a 0, stanoveni jeho priority(0 az 3) */ 
	NVIC_SetPriority(TIM2_IRQn,0);
	NVIC_SetPriority(SysTick_IRQn,2); // set priority for systick pouziva se pro LCD

	/* Enable the Systick interrupt*/
	NVIC_EnableIRQ(SysTick_IRQn );  // for delay generate
  /* Enable the TIM2 global Interrupt */
 // NVIC_EnableIRQ(TIM2_IRQn); // handler se musi jmenovat stejne 
}
	
