/**********************************************************************************************************************
*	Mereni frekvence neprmou metodou, mereni delky periody, delky kladne a zaporne casti pulsu, mereni stridy
*
* Program byl napsan pro mikrokontroler ARM Cortex STM32F051R8 ve vyvojovem kitu STM32F0-Discovery
*	Vstup citace TIM2 je na pinu PA5. Je mozne pouzit take jine prubehy nez obdelnik, potom
* musi jit signal prez vnitrni komparator COMP1. Vstup komparatoru PA1, vystup PA6. Propojeni se
* vstupem casovace dratovou propojkou.
* Nastavovani zobrazeni pomoci tlacitka na pinu PA0 spina proti GND.
* Zobrazovani LCD displejem 2x16znaku pripojeni na port B, definice pinu v souboru "stm32f0xx_LCD.h"
* Z duvodu velk chyby nactenych pulsu byla ve funkci "SysTick_Handler" provedena korekce poctu nactenych pulsu do 
* promenych "ccr1", "ccr2"
*
* Autor: Pavel Novotn
*	Date:  04/2013
* Licence: freeware
************************************************************************************************************************/


#include "system_stm32f0xx.h"
#include "stm32f0xx_my_config.h"
#include "stm32f0xx_gpio.h"
#include "stm32f0xx_rcc.h"
#include "core_cm0.h"
#include "stm32f0xx_LCD.h"
#include "obsluha_rozhrani_HMI.h"
#include "frekvence.h"
#include "main.h"
#include "stdint.h"


/* Private variables ---------------------------------------------------------*/
static __IO uint32_t TimingDelay;		//pro zpozdeni pocita preruseni realizovane SYSTICK
enum {FREQ,PERIOD,KLADNA,ZAPORNA,STRIDA}typy_hodnot;

extern uint8_t poz_hodnota;

extern uint8_t refr_udaj_display;  // pozadavek na prekresleni hodnotz na displeji

extern float frekvence;
extern float perioda;
extern float delka_kladna;
extern float delka_zaporna;
extern float strida;

/* funkcni prototypy-----------------------------------------------------------*/

/**
  * @brief  Nastaveni periferi, smycka DDS generatoru
  * @param  None
  * @retval None
  */
int main (void)
{ 	
	NVIC_my_config();		 				// volani nastaveni preruseni a priorit
	GPIO_my_config();						// konfiguruje PA0 jako vstup pro ovladaci tlacitka, PC8,9 jako vystupy pro LED na vyvojovem kitu
	SYSTICK_my_config(); 				// konfigurace periferie SYSTICK
	frequencySetTIM2();					// konfigurace TIM2 pro neprime mereni frekvence				

	LCD_my_config();						// volani funkce inicializujici display	
	display_start_text();       // text pocatecniho nastaveni

	spust_odbery();
	
	/************************************************************************************************************************/
	/**********************************************  HLAVNI SMYCKA   ********************************************************/
	/************************************************************************************************************************/
	while(1)
	{	// test na stisk tlacitka
	if(!(GPIO_ReadInputDataBit(GPIOA, GPIO_Pin_0)))
		{ 
			zmen_zobrazeni();				// zmeni druh zobrazovanou hodnotu mereni na displeji
		}
		if(refr_udaj_display)
		{
			GPIOC->ODR|=0x200;			//rozsvitit LED PC9/
			zobraz_data();					// aktualizuj data na displeji
			GPIOC->ODR&=~0x200; 		//zhasnout LED PC9/
		}
	}
} // end of main()


/**
  * @brief  Zobrazi pozadovana data na LCD display
  * @param  None
  * @retval None
  */
void zobraz_data()   
{
	switch(poz_hodnota)
			{
				case(FREQ):zobraz_data_signal(frekvence*1000,3);break;    				// zobrazi (text,pocet desetinych mist)
				case(PERIOD):zobraz_data_signal(perioda*1000000000,6);break;
				case(KLADNA):zobraz_data_signal(delka_kladna*1000000000,6);break;
				case(ZAPORNA):zobraz_data_signal(delka_zaporna*1000000000,6);break;
				case(STRIDA):zobraz_data_signal(strida*10000,4);break;
			}
			refr_udaj_display=0;  // bit display byl aktualizovan 
}

/**
  * @brief  Realizuje zpozdeni, kvantum je dane SYSTICK nastavene na 1ms
  * @param  : nTime hodnota casu zpozdeni
  * @retval : none
  */
void Delay(__IO uint32_t nTime)
{ 
  TimingDelay = nTime;
  while(TimingDelay != 0);   
}

void TimingDelay_Decrement(void)  // volana periodicky z obsluhy preruseni systick generuje delay pulsy
{	
  if (TimingDelay != 0x00)
  { 
    TimingDelay--;
  }
}

 
