/******************************************************************************************************
*	Impulsni generator pomoci PWM
*
* Program byl napsan pro mikrokontroler ARM Cortex STM32F051R8
*	Program umoznuje generovat impulsy nebo testovat online vlastnosti PWM.
* Pomoci tim2_arr nastavujeme opakovaci periodu vystupniho signalu,
*	pomoci tim2_ccr1 nastavujeme dlku pulsu (stridu).
* Vystupni pin pro PWM je PA15
* Nastavovani pomoci trech tlacitek proti zemi na pinech PA0=SET, PA1=plus, PA2=minus.
* Zobrazovani LCD displejem 2x16znaku pripojeni na port B, definice pinu v souboru "stm32f0xx_LCD.h"
*
* Autor: Pavel Novotn
*	Date:  04/2013
* Licence: freeware
***********************************************************************************************************/


#include "system_stm32f0xx.h"
#include "stm32f0xx_my_config.h"
#include "stm32f0xx_gpio.h"
#include "stm32f0xx_rcc.h"
#include "core_cm0.h"
#include "stm32f0xx_LCD.h"
#include "obsluha_rozhrani_HMI.h"
#include "main.h"
#include "stdint.h"
#include "PWM_generator.h"

/* Types define----------------------------------------------------------------*/

/* Global variables ----------------------------------------------------------*/

/* Private variables ---------------------------------------------------------*/
static __IO uint32_t TimingDelay;		//pro zpozdeni pocita preruseni realizovane SYSTICK
enum {ARR,CCR1}typy_hodnot; 				//ARR alias pro "0", CCR1 alias pro "1"

/* funkcni prototypy-----------------------------------------------------------*/

/**
  * @brief  Nastaveni periferi
  * @param  None
  * @retval None
  */
int main (void)
{ 	
	NVIC_my_config();		 				// volani nastaveni preruseni a priorit
	GPIO_my_config();						// Konfiguruje PA0,1,2 jako vstupy pro ovladaci tlacitka, PC8,9 jako vystupy pro LED na vyvojovem kitu
	SYSTICK_my_config(); 				// volani nastaveni periferie SYSTICK	
	LCD_my_config();						// volani funkce inicializujici display
	display_start_text();       // text pocatecniho nastaveni
	PWM_SetTIM2();							// konfigurace TIM2 pro generovani PWM	
	
	/************************************************************************************************************************/
	/**********************************************  HLAVNI SMYCKA   ********************************************************/
	/************************************************************************************************************************/
	
	while(1)  //nekonecna hlavni smycka
	{	
	if(!(GPIO_ReadInputDataBit(GPIOA, GPIO_Pin_0)))  // testovani stisku tlacitka SET
		{ 	
			GPIOC->ODR|=0x200;			 				//rozsviceni LED PC9								
			display_zobraz_rezim(ARR);	 		//zobrazen nastavovane hodnoty 
			nastav_hodnotu(&(TIM2->ARR));		//nastaveni opakovaci frekvence registrem ARR
			
			display_zobraz_rezim(CCR1);			//zobrazen nastavovane hodnoty 
			nastav_hodnotu(&(TIM2->CCR1));	//nastaveni sirky pulsu compare registrem ccr1
			GPIOC->ODR&=~0x200; 						//zhasnuti LED PC9 na konci vstupu 
			display_start_text();						//zobrazeni defaultni obrazovky
		}
		
	}
} // end of main()

/**
  * @brief  Realizuje zpozdeni, kvantum je dane SYSTICK nastavene na 1ms
  * @param  : nTime hodnota casu pro realizaci zpozdeni
  * @retval : none
  */
void Delay(__IO uint32_t nTime)
{ 
  TimingDelay = nTime;
  while(TimingDelay != 0);   
}

void TimingDelay_Decrement(void)  // volana periodicky z obsluhy preruseni systick generuje delay pulsy
{	
  if (TimingDelay != 0x00)
  { 
    TimingDelay--;
  }
}

 
