/**
  ******************************************************************************
  * @file    SysTick/stm32f0xx_it.c 
  * @author  MCD Application Team
  * @version V1.0.0
  * @date    23-March-2012
  * @brief   Main Interrupt Service Routines.
  *          This file provides template for all exceptions handler and 
  *          peripherals interrupt service routine.
  ******************************************************************************
  * @attention
  *
  * <h2><center>&copy; COPYRIGHT 2012 STMicroelectronics</center></h2>
  *
  * Licensed under MCD-ST Liberty SW License Agreement V2, (the "License");
  * You may not use this file except in compliance with the License.
  * You may obtain a copy of the License at:
  *
  *        http://www.st.com/software_license_agreement_liberty_v2
  *
  * Unless required by applicable law or agreed to in writing, software 
  * distributed under the License is distributed on an "AS IS" BASIS, 
  * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  * See the License for the specific language governing permissions and
  * limitations under the License.
  *
  ******************************************************************************
  */ 

/* Includes ------------------------------------------------------------------*/
#include "stm32f0xx_it.h"
#include "stm32f0xx_LCD.h"
#include "stm32f0xx_rcc.h"
#include "stm32f0xx_gpio.h"
#include "stm32f0xx_tim.h"
#include "obsluha_klaves_generator.h"
#include "main.h"

/** @addtogroup STM32F0_Discovery_Peripheral_Examples
  * @{
  */

/** @addtogroup SysTick_Example
  * @{
  */ 

/* Private typedef -----------------------------------------------------------*/
/* Private define ------------------------------------------------------------*/
/* Private macro -------------------------------------------------------------*/
/* Global variables ---------------------------------------------------------*/
extern uint8_t LCD_text[];
extern uint32_t faze;
/* Private variables ---------------------------------------------------------*/
uint16_t capture = 0;
int nastaveni=0; // stav procesu nastaveni

/* Private function prototypes -----------------------------------------------*/
/* Private functions ---------------------------------------------------------*/

/******************************************************************************/
/*            Cortex-M0 Processor Exceptions Handlers                         */
/******************************************************************************/

/**
  * @brief  This function handles NMI exception.
  * @param  None
  * @retval None
  */
void NMI_Handler(void)
{
}

/**
  * @brief  This function handles Hard Fault exception.
  * @param  None
  * @retval None
  */
void HardFault_Handler(void)
{
  /* Go to infinite loop when Hard Fault exception occurs */
  while (1)
  {
  }
}

/**
  * @brief  This function handles SVCall exception.
  * @param  None
  * @retval None
  */
void SVC_Handler(void)
{
}

/**
  * @brief  This function handles PendSVC exception.
  * @param  None
  * @retval None
  */
void PendSV_Handler(void)
{
}

/**
  * @brief  This function handles SysTick Handler.
  * @param  None
  * @retval None
  */

/******************************************************************************/
/*                 STM32F0xx Peripherals Interrupt Handlers                   */
/*  Add here the Interrupt Handler for the used peripheral(s) (PPP), for the  */
/*  available peripheral interrupt handler's name please refer to the startup */
/*  file (startup_stm32f0xx.s).                                            */
/******************************************************************************/

/**
  * @brief  Obsluha externiho preruseni od SYSTICK
  * @param  : None
  * @retval : None
  */
void SysTick_Handler(void)
{
 TimingDelay_Decrement();
}

/**
  * @brief  Obsluha externiho preruseni od tlacitka PA0
  * @param  : None
  * @retval : Faze a tvar signalu.
  */
void EXTI0_1_IRQHandler(void)
{ /*prechodne povoleni hodin do periferii a povoleni SYSTICK, behem chodu nebudou zpomalovat generator*/
	RCC_AHBPeriphClockCmd(RCC_AHBPeriph_GPIOA, ENABLE);  
  RCC_AHBPeriphClockCmd(RCC_AHBPeriph_GPIOC, ENABLE);
	NVIC_EnableIRQ(SysTick_IRQn );
					
				GPIO_WriteBit(GPIOC, GPIO_Pin_8, Bit_SET);	// zmena stavu pinu LED on indikace vstup do nastaveni gen.
				LCD_Clear();
				set_cursor(0,0);	 			 // nastavi pozici cursoru LCD na (sloupec, radek)
					printLCD("Nast.frekv. tl.+");
				set_cursor(0,1);
					printLCD("Nast.tvaru  tl.-");

		  while(GPIO_ReadInputDataBit(GPIOA, GPIO_Pin_0)){} // ve smycce pokud bude nekdo drzet tlacitko 
				Delay(50);
				
			nastaveni=0; //detekuje zda uz probehlo nastaveni parametru generatoru
				// volba nastaveni frekvence nebo tvar vystupniho signalu
			while(nastaveni==0)  // test na uvolnene tlacitko na PA0
			{	
				if(!GPIO_ReadInputDataBit(GPIOA, GPIO_Pin_1)){nastav_fazi();nastaveni=1;} 	// po stisku tlac. PA1 "+"
				if(!GPIO_ReadInputDataBit(GPIOA, GPIO_Pin_2)){nastav_prubeh();nastaveni=1;}	// po stisku tlac. PA2 "-"
				if(GPIO_ReadInputDataBit(GPIOA, GPIO_Pin_0))break;  // po stisku tlac. PA0 se opusti nastavovani generatoru
			}
			
			LCD_Clear();
			zobraz_data_signal();  	// na display zobrazi aktualne nastavenou frekvenci a tvar signalu
			GPIO_WriteBit(GPIOC, GPIO_Pin_8, Bit_RESET);	//  LED off  konec zadavani
			EXTI->PR |= EXTI_PR_PR0 ;     // reset preruseni
	
/* vypnuti a deaktivace hodin periferie	GPIO a preruseni od SYSTICK	*/	
	RCC_AHBPeriphClockCmd(RCC_AHBPeriph_GPIOA, DISABLE);  // deaktivace hodin periferie
//  RCC_AHBPeriphClockCmd(RCC_AHBPeriph_GPIOC, DISABLE);
	NVIC_DisableIRQ(SysTick_IRQn );
}
/**
  * @brief  This function handles PPP interrupt request.
  * @param  None
  * @retval None
  */
/*void PPP_IRQHandler(void)
{
}*/

/**
  * @}
  */ 

/**
  * @}
  */ 

/************************ (C) COPYRIGHT STMicroelectronics *****END OF FILE****/
