/* DDS generator
*  Program pro mikrokontroler ARM Cortex STM32F051R8 testovano na modulu STM32F0-Discovery
*  genertor signlu sinus, pila, obdelnik pracujici na principu prime cislicove synteze DDS
*  rozsah nastavitelnych frekvenci 0-500kHz, od 300 do 500kHz signal zkresleny problem s rychlosti prebehu
*  Nastavovani pomoci trech tlacitek na pinech PA0 proti +3 V, PA1,2 proti GND.
*  Zobrazovani LCD displejem 2x16znaku pripojeni na port B, definice pinu v souboru "stm32f0xx_LCD.h"
*  Autor: Pavel Novotn
*	 Date:  12/2012
*  Licence: freeware
*/




#include "system_stm32f0xx.h"
#include "stm32f0xx_my_config.h"
#include "stm32f0xx_gpio.h"
#include "stm32f0xx_rcc.h"
#include "core_cm0.h"
#include "stm32f0xx_LCD.h"
#include "main.h"
#include "stdint.h"
#include "arm_math.h"

/* Types define----------------------------------------------------------------*/


/* Private variables ---------------------------------------------------------*/
#define Ns 1024										// pocet vzorku prubehu
#define Rozl 4096									// maximalni rozliseni DAC 0-4095 prevodniku konstanta nemenit!!!
#define P2P  150									// Peek to Peek uprava rozkmitu zmensi vykyv prubehu kvuli chybam pri vypoctu sinusovky(presahy
int scale_freq=2240;							// prevodni konstanta nastaveni faze frekvence zmenit pri jine CLK CPU
unsigned short int poleDat[Ns];   // pole pro ulozeni bodu prubehu
uint32_t DAC_value;  							// adresa z ktere se kopiruje DMA prubeh na DAC
static __IO uint32_t TimingDelay;
uint32_t  faze;

/* funkcni prototypy-----------------------------------------------------------*/
void delay(int);

/**
  * @brief  Nastaveni periferi, smycka DDS generatoru
  * @param  None
  * @retval None
  */
int main (void)
{ 	 
	uint32_t souctovy_reg=0;    // registr faze signalu
	uint32_t mask_adr=0;				// maska adresy s ulozenym prubehem signalu 
	
	GPIO_my_config();						// nastaveni periferie obecnych vstupu vystupu
	EXTI_my_config();  					// nastaveni externiho preruseni pri stisku tlacitka na PA0
	SYSTICK_my_config(); 				// nastaveni periferie SYSTICK
	NVIC_my_config();		 				// nastaveni preruseni
	DAC_my_config();		 				// nastaveni DCA periferie
	LCD_my_config();
	
	LCD_Clear();								// smazani LCD displaye
	set_cursor(0,0);	 				  // nastavi pozici cursoru LCD na (sloupec, radek)
		printLCD(" DDS generator  ");
	set_cursor(0,1);
		printLCD("Stiskni  tl. SET");
	
	mask_adr=0x20-ilogb(Ns); 		// vypocet masky adresy s ulozenym prubehem signalu v zavislosti na rozsahu Ns(prostor pole pro ulozani dat)
	
	/************************************************GENEROVANI SIGNALU DDS********************************************************/
	while(1)
	{	// realizace DDS Direct digital synteza
		/*
		//nasledujic kod zpozdi smycku o cca 1us umozni sledovat okamziky generovani dat
		if(GPIOC->ODR&0x200) 			// kdyz je rozsvicena LED PC9
			{GPIOC->ODR&=~0x200;} 	//zhasnout LED PC9 
			else
			{GPIOC->ODR|=0x200;} 		//rozsvitit LED PC9*/
		souctovy_reg=faze+souctovy_reg;
	  DAC->DHR12R1=(uint32_t)poleDat[(souctovy_reg>>mask_adr)];// posun o 22bitu je vymaskovn hornch 10 bitu adresy do pameti
	}
} // end of main()

/**
  * @brief  Vypocet dat a ulozeni pro generovani sinu
  * @param  : None
  * @retval : Global area poleDat[]
  */
void createTabSin()
{
	int t;
  int p=0;   
	float x=0;
	float vypocet=0;
	float pom;
	
/* vpocet druh poloviny sinusoidy */
	for(t=Ns/2;t<Ns;t++)  
	{
	x=(float)p*3142/Ns/500; // kroky pro body vypoctu fce
		// computing Taylor polynom value of sin function
	vypocet=x-(x*x*x)/6+(x*x*x*x*x)/120-(x*x*x*x*x*x*x)/5040+(x*x*x*x*x*x*x*x*x)/362880-(x*x*x*x*x*x*x*x*x*x*x)/39916800;
	pom=-vypocet*((Rozl-P2P)/2)+(Rozl/2);
	poleDat[p+Ns/2]=(int)pom;
	p=p+1;
	}
	
/* uprava a koprovani hodnot do prvn poloviny sinusoidy, bere hodnoty z predchoziho vpoctu druhe poloviny sinu*/
	p=0; 															 // nulovani ukazatele do pameti prubehu
	for (t=0;t<Ns/2;t++)  
	{
  poleDat[p]=-poleDat[Ns-1-p]+Rozl;
	p=p+1;  													//ukazatel do pole vysledku pro ukladani
	}
	set_cursor(0,1);	 			 					// nastavi pozici cursoru LCD na (sloupec, radek)
	printLCD("Nacteno    Sinus");
	Delay(1200);  
}

/**
  * @brief  Vypocet dat a ulozeni pro generovani pily
  * @param  : None
  * @retval : Global area poleDat[]
  */
void createTabPila()
{		
	int t;
	float vypocet=0;
	float dilek=0;
	dilek=Rozl/Ns;
	
	for(t=0;t<Ns;t++)  
	{
		vypocet=t*dilek;
	poleDat[t]=(int)vypocet;
	}
	set_cursor(0,1);	 							 // nastavi pozici cursoru LCD na (sloupec, radek)
	printLCD("Nacteno     Pila");
	Delay(1200);
}

/**
  * @brief  Vypocet dat a ulozeni pro generovani Obdelniku
  * @param  : None
  * @retval : Global area poleDat[]
  */
void createTabObdelnik()
{
	int t;
	/* vpocet a zapis prvni poloviny obdelnikoveho signalu */
		for (t=0;t<Ns/2;t++)  
	{
  poleDat[t]=0;
	}
	/* vpocet a zapis druh poloviny obdelnikoveho signalu */
	for(t=Ns/2;t<Ns;t++)  
	{
	poleDat[t]=Rozl-1;
	}
	set_cursor(0,1);	 						 // nastavi pozici cursoru LCD na (sloupec, radek)
	printLCD("Nacteno Obdelnik");
	Delay(1200);
}

/**
  * @brief  Realizuje zpozdeni, kvantum je dane SYSTICK nastavene na 1ms
  * @param  : nTime hodnota casu pro realizaci zpozdeni
  * @retval : Global area poleDat[]
  */
void Delay(__IO uint32_t nTime)
{ 
  TimingDelay = nTime;
  while(TimingDelay != 0);   
}

void TimingDelay_Decrement(void)  // volana periodicky z obsluhy preruseni systick povolene pouze pri preruseni EXTI
{	
  if (TimingDelay != 0x00)
  { 
    TimingDelay--;
  }
}

 
