/**
  ******************************************************************************
  * @file    SysTick/stm32f0xx_it.c 
  * @author  MCD Application Team
  * @version V1.0.0
  * @date    23-March-2012
  * @brief   Main Interrupt Service Routines.
  *          This file provides template for all exceptions handler and 
  *          peripherals interrupt service routine.
  ******************************************************************************
  * @attention
  *
  * <h2><center>&copy; COPYRIGHT 2012 STMicroelectronics</center></h2>
  *
  * Licensed under MCD-ST Liberty SW License Agreement V2, (the "License");
  * You may not use this file except in compliance with the License.
  * You may obtain a copy of the License at:
  *
  *        http://www.st.com/software_license_agreement_liberty_v2
  *
  * Unless required by applicable law or agreed to in writing, software 
  * distributed under the License is distributed on an "AS IS" BASIS, 
  * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  * See the License for the specific language governing permissions and
  * limitations under the License.
  *
  ******************************************************************************
  */ 

/* Includes ------------------------------------------------------------------*/
#include "stm32f0xx_it.h"
#include "stm32f0xx_LCD.h"
#include "stm32f0xx_rcc.h"
#include "stm32f0xx_gpio.h"
#include "stm32f0xx_tim.h"
#include "obsluha_rozhrani_HMI.h"
#include "main.h"

/** @addtogroup STM32F0_Discovery_Peripheral_Examples
  * @{
  */

/** @addtogroup SysTick_Example
  * @{
  */ 

/* Private typedef -----------------------------------------------------------*/
/* Private define ------------------------------------------------------------*/
/* Private macro -------------------------------------------------------------*/
/* Global variables ---------------------------------------------------------*/
extern uint8_t LCD_text[];
extern uint32_t zbyva_vzorku; // pristup k promenne zbyva vzorku k ulozeni
extern uint8_t datalog_bezi;  // infomace o probihajicim mereni pro zobrazeni na displeji

/* Private variables ---------------------------------------------------------*/
int nastaveni=0; 							// stav procesu nastaveni
uint8_t refresh_LCD=0;				// info zda je treba prekreslit display
uint16_t ADC_akt_hodnota;			// aktualni hodnota ADC

/* Private function prototypes -----------------------------------------------*/
/* Private functions ---------------------------------------------------------*/

/******************************************************************************/
/*            Cortex-M0 Processor Exceptions Handlers                         */
/******************************************************************************/

/**
  * @brief  This function handles NMI exception.
  * @param  None
  * @retval None
  */
void NMI_Handler(void)
{
}

/**
  * @brief  This function handles Hard Fault exception.
  * @param  None
  * @retval None
  */
void HardFault_Handler(void)
{
  /* Go to infinite loop when Hard Fault exception occurs */
  while (1)
  {
  }
}

/**
  * @brief  This function handles SVCall exception.
  * @param  None
  * @retval None
  */
void SVC_Handler(void)
{
}

/**
  * @brief  This function handles PendSVC exception.
  * @param  None
  * @retval None
  */
void PendSV_Handler(void)
{
}

/**
  * @brief  This function handles SysTick Handler.
  * @param  None
  * @retval None
  */

/******************************************************************************/
/*                 STM32F0xx Peripherals Interrupt Handlers                   */
/*  Add here the Interrupt Handler for the used peripheral(s) (PPP), for the  */
/*  available peripheral interrupt handler's name please refer to the startup */
/*  file (startup_stm32f0xx.s).                                            */
/******************************************************************************/

/**
  * @brief  Obsluha externiho preruseni od SYSTICK
  * @param  : None
  * @retval : None
  */
void SysTick_Handler(void)
{
 TimingDelay_Decrement(); //pouzito pro zpozdeni
}

/**
  * @brief  Obsluha externiho preruseni od tlacitka PA0
  * @param  : None
  * @retval : Nastavena faze a tvar signalu.
  */
void EXTI0_1_IRQHandler(void)
{ /*prechodne povoleni hodin do periferii a povoleni SYSTICK, behem chodu nebudou zpomalovat generator*/
	RCC_AHBPeriphClockCmd(RCC_AHBPeriph_GPIOA, ENABLE);  
	NVIC_EnableIRQ(SysTick_IRQn );
	GPIO_WriteBit(GPIOC, GPIO_Pin_9, Bit_SET);	 					//  LED off  konec zadavani
					
		  while(GPIO_ReadInputDataBit(GPIOA, GPIO_Pin_0)){} // ve smycce pokud bude nekdo drzet tlacitko 
				Delay(50);

			nastav_parametry();				
						
			refresh_LCD=1;     // zadost o obnoveni dat na mericim displeji zpusobi volani obnovovaci funkce z main
				
			GPIO_WriteBit(GPIOC, GPIO_Pin_9, Bit_RESET);	//  LED off  konec zadavani
			EXTI->PR |= EXTI_PR_PR0 ;                     // reset preruseni
	
/* vypnuti a deaktivace hodin periferie	GPIO a preruseni od SYSTICK	*/	
	 RCC_AHBPeriphClockCmd(RCC_AHBPeriph_GPIOA, DISABLE);  // deaktivace hodin periferie
  //	NVIC_DisableIRQ(SysTick_IRQn );
}

/**
  * @brief   Obsluha preruseni od Timer2
  * @param  : None
  * @retval : Ziskany vzorek hodnota z ADC
  */
void TIM2_IRQHandler (void)
{ // if ((TIM2->SR & 0x0001) != 0)       // check interrupt source 
  // {	
   if(GPIOC->ODR&0x100) 		// kdyz je rozsvicena LED PC8
	 {GPIOC->ODR&=~0x100;} 		//zhasnout LED PC8 
		else
		{GPIOC->ODR|=0x100;} 		//rozsvitit LED PC8/
	
		 ADC_akt_hodnota=ADC1_Read();   // odecet hodnoty z ADC prevodniku
		 zbyva_vzorku--;
	 	
		 if(zbyva_vzorku<=0) 		//zastaveni mereni pokud uz nezbyvaji vzorky ke cteni
		 {
			 GPIOC->ODR&=~0x100; 	//zhasnout LED PC8
			 datalog_bezi=0; 
			 stop_odbery();
		 }
		 refresh_LCD=1;    			// zadost o obnoveni dat na mericim displeji zpusobi volani obnovovaci funkce z main
		 TIM2->SR &= ~0x3;  
  // }
		 	
}
/**
  * @brief  This function handles PPP interrupt request.
  * @param  None
  * @retval None
  */
/*void PPP_IRQHandler(void)
{
}*/

/**
  * @}
  */ 

/**
  * @}
  */ 

/************************ (C) COPYRIGHT STMicroelectronics *****END OF FILE****/
