/*Konfigurace periferi STM32F051*/


#include "stm32f0xx_my_config.h"
#include "stm32f0xx_gpio.h"
#include "stm32f0xx_rcc.h"
#include "stm32f0xx_adc.h"
#include "stm32f0xx_LCD.h"
#include "stm32f0xx_exti.h"
#include "main.h"


GPIO_InitTypeDef GPIO_InitStructure;
ADC_InitTypeDef  ADC_InitStructure;
EXTI_InitTypeDef EXTI_InitStructure;
RCC_ClocksTypeDef RCC_Clocks;

extern uint8_t storage [];	

/********************************* GPIO **************************************/
/**
  * @brief  Inicializace vstunu a vystupu MCU
  * @param  : None
  * @retval : Nastaveni GPIO
  */
void GPIO_my_config(void)
 {   
  /* GPIOx Periph clock enable */
	RCC_AHBPeriphClockCmd(RCC_AHBPeriph_GPIOA, ENABLE);
  RCC_AHBPeriphClockCmd(RCC_AHBPeriph_GPIOC, ENABLE);
	 
 /* Configure PC8 as output pushpull mode */
  GPIO_InitStructure.GPIO_Pin = GPIO_Pin_8|GPIO_Pin_9;
  GPIO_InitStructure.GPIO_Mode = GPIO_Mode_OUT;
  GPIO_InitStructure.GPIO_OType = GPIO_OType_PP;
  GPIO_InitStructure.GPIO_Speed = GPIO_Speed_50MHz;
  GPIO_InitStructure.GPIO_PuPd = GPIO_PuPd_NOPULL;
  GPIO_Init(GPIOC, &GPIO_InitStructure);
	 
	  /* Configure PA0 in input*/
  GPIO_InitStructure.GPIO_Pin = GPIO_Pin_0;
  GPIO_InitStructure.GPIO_Mode = GPIO_Mode_IN;
  GPIO_InitStructure.GPIO_OType = GPIO_OType_OD;
  GPIO_InitStructure.GPIO_Speed = GPIO_Speed_50MHz;
  GPIO_InitStructure.GPIO_PuPd = GPIO_PuPd_NOPULL;
  GPIO_Init(GPIOA, &GPIO_InitStructure);
	 
	GPIO_InitStructure.GPIO_Pin = GPIO_Pin_1|GPIO_Pin_2;
  GPIO_InitStructure.GPIO_Mode = GPIO_Mode_IN;
  GPIO_InitStructure.GPIO_OType = GPIO_OType_OD;
  GPIO_InitStructure.GPIO_Speed = GPIO_Speed_50MHz;
  GPIO_InitStructure.GPIO_PuPd = GPIO_PuPd_UP;
  GPIO_Init(GPIOA, &GPIO_InitStructure);
	
 } 
 
/***************************************** LCD display *****************************************/
 /**
  * @brief  Inicializace LCD displeje
  * @param  : None
  * @retval : Nastaveni GPIO pro dicplej
  */
void LCD_my_config(void) 
 {
			RCC_AHBPeriphClockCmd(RCC_AHBPeriph_GPIOB, ENABLE);
	 /* Configure the GPIO Pins for LCD.*/
     
      GPIO_InitStructure.GPIO_Pin = LCD_E |LCD_RW | LCD_RS | LCD_D4 | LCD_D5
                      | LCD_D6 | LCD_D7 ;  
			GPIO_InitStructure.GPIO_Mode = GPIO_Mode_OUT;
      GPIO_InitStructure.GPIO_OType = GPIO_OType_PP;
      GPIO_InitStructure.GPIO_Speed = GPIO_Speed_50MHz;
      GPIO_Init(GPIOB, &GPIO_InitStructure);
			LCD_Init();   // inicializace display 4 bit komunikace
 }
 
/******************************************** DMA **********************************************/
 /**
  * @brief  Inicializace DMA periferie
  * @param  : None
  * @retval : Nastaveni DMA
  */
 void DMA_my_config(uint16_t pocet_vzorku)   
{
	DMA1_Channel1->CCR&=~0x1; 				//DMA kanal disable
	RCC->AHBENR|=0x1;										// DMA clock enable
 	DMA1_Channel1->CPAR=0x40012440;        //adresa odkud budu data scanovat ADC1->DR
	DMA1_Channel1->CMAR=(uint32_t)&storage[0]; 	//pocatecni adresa kam budu data scanovat	
	DMA1->IFCR|=0x0F; 								//reset interrupt flags
	DMA1_Channel1->CCR|=0x0080; 								// memory increment mode
	DMA1_Channel1->CNDTR=pocet_vzorku;			  //mnozstvi dat  ktere bude preneseno DMA max: 65353dec
	DMA1_Channel1->CCR|=0x1; 				//DMA kanal enable
}	

/**************************************** USART **********************************************/
/**
  * @brief  Inicializace USART pro prenos RS232
  * @param  : None
  * @retval : None
  */
void USART_my_config()   
{ 
  GPIOA->MODER|=0x280000;					//nastaveni PA9 a PA10 na AF		
	GPIOA->AFR[1]|=0x110;						//nastaveni PA9 a PA10 na AF1(USART1)
	GPIOC->PUPDR=0x40000;						//pullup na PA9 
	
	RCC->APB2ENR|=0x4000;						//zapnuti hodin pro USART1	
	USART1->BRR=0x1388;             //nastaveni baudrate na 9600 Baud (0x1A0 je pro 115200baude)	
	USART1->CR1|=0x2D;							//nastaveni 8bit,1stop bit,bez parity, povoleni preruseni pri prichodu dat z USATU, povoleni RX,TX, celkove zapnuti usartu
}

/******************************************** EXTI *******************************************/
/**
  * @brief  Inicializace EXTI externi preruseni
  * @param  : None
  * @retval : None
  */
void EXTI_my_config()
{
	RCC_APB2PeriphClockCmd(RCC_APB2Periph_SYSCFG, ENABLE);
	
	SYSCFG->EXTICR[0] |= SYSCFG_EXTICR1_EXTI0_PA;  // zdroj EXTI bude pin PA0
 	
  EXTI_StructInit(&EXTI_InitStructure);
	EXTI_InitStructure.EXTI_Line = EXTI_Line0;
  EXTI_InitStructure.EXTI_Mode = EXTI_Mode_Interrupt;
  EXTI_InitStructure.EXTI_Trigger = EXTI_Trigger_Rising;
  EXTI_InitStructure.EXTI_LineCmd = ENABLE;
  EXTI_Init(&EXTI_InitStructure);
	 /* Clear SC EXTI Line Pending Bit */
  EXTI_ClearITPendingBit(EXTI0_1_IRQn);

}

/**************************************** ADC *******************************************/
/**
  * @brief  Inicializace ADC, GPIOA pin4 
  * @param  : None
  * @retval : None
  */
	void ADC_my_config(void)
 {  
	 /* ADC1 Periph clock enable */
  RCC_APB2PeriphClockCmd(RCC_APB2Periph_ADC1, ENABLE);
	 /* Initialize ADC 14MHz RC*/
 // RCC_ADCCLKConfig(RCC_ADCCLK_HSI14);      //14MHz RC OSC 
 // RCC_HSI14Cmd(ENABLE);                    //14MHz RC OSC start pro ADC
	
	// povolime hodiny do portu 
 // RCC_APB2PeriphClockCmd(RCC_AHBPeriph_GPIOC, ENABLE);
  GPIO_InitStructure.GPIO_Pin = GPIO_Pin_4;    // tady pripojime merene napeti
  // GPIO_InitStructure.GPIO_Speed = GPIO_Speed_50MHz;
  GPIO_InitStructure.GPIO_Mode = GPIO_Mode_AN;
	GPIO_InitStructure.GPIO_PuPd = GPIO_PuPd_NOPULL ;
  GPIO_Init(GPIOC, &GPIO_InitStructure);
	 
	 	// ADCs DeInit   
  ADC_DeInit(ADC1);

  // Initialize ADC structure 
  ADC_StructInit(&ADC_InitStructure);
 
  // ADC1 Configuration ------------------------------------------------------
  ADC_InitStructure.ADC_Resolution          	= ADC_Resolution_8b;
  ADC_InitStructure.ADC_ContinuousConvMode  	= DISABLE;
  ADC_InitStructure.ADC_ExternalTrigConvEdge  = ADC_ExternalTrigConvEdge_Rising; 
	ADC_InitStructure.ADC_ExternalTrigConv   	  = ADC_ExternalTrigConv_T2_TRGO;  		//spousti casovac tim2
  ADC_InitStructure.ADC_DataAlign           	= ADC_DataAlign_Right;
  ADC_InitStructure.ADC_ScanDirection         = ADC_ScanDirection_Upward ;
  ADC_Init( ADC1, &ADC_InitStructure );
 
  // ADC1 Regular Channel 14 
  ADC_ChannelConfig( ADC1, ADC_Channel_14, ADC_SampleTime_1_5Cycles);
 
  //  ADC1 continuous mode 
	// ADC_ContinuousModeCmd(ADC1, ENABLE);
	
	ADC_OverrunModeCmd(ADC1, DISABLE);
 
  // Provedeme kalibraci prevodniku 
	ADC_GetCalibrationFactor(ADC1);	

	ADC1->CFGR1|=0x3;  // umistit az za kalibraci jinak nacte prvni vzorek!!! DMAEN + circular mode jeden vzorek za druhym
	//  ADC1 neceka se na vycteni data registru ten obsahuje jen posledni data
	
	//aktivace ADCperiferie	 
  ADC_Cmd(ADC1, ENABLE);
 
  // Wait the ADCEN falg 
  while(!ADC_GetFlagStatus(ADC1, ADC_FLAG_ADEN)); 

 /* ADC1 regular Software Start Conv */ 
  ADC_StartOfConversion(ADC1);
 }	
/**************************************** TIMER *******************************************/
 /**
  * @brief  Inicializace TIM2 32bitu
  * @param  : None
  * @retval : 
  */
void TIMER_my_config()
{	
	RCC_APB1PeriphClockCmd(RCC_APB1Periph_TIM2, ENABLE);
	  /* Compute the prescaler value */
  //PrescalerValue = (uint16_t) (SystemCoreClock  / 6000000) - 1;

  /* Time base configuration */
  TIM2->CR1|=0x80;  // ARPE enable autoreload register
  TIM2->PSC=48000;
  TIM2->CR1|=0x10;  	// DIR=0 upcount
	TIM2->CR1|=0x4;  		// URS overflow/underflow or DMA request generate interrupt
	TIM2->CR2|=0x020;		// UG update generate TRG0 output for trigger ADC
	TIM2->DIER|=0x1;  	//UIE update interrupt enable
}

/**************************************** SYSTICK *******************************************/
/**
  * @brief  Inicializace SYSTICK
  * @param  : None
  * @retval : None
  */
void SYSTICK_my_config() 
{	 /* SysTick end of count event each 1ms */
  RCC_GetClocksFreq(&RCC_Clocks);
  SysTick_Config(RCC_Clocks.HCLK_Frequency / 1000);  //vyrabi preruseni po 1 ms 
}

/*************************************** NVIC *******************************************/
/**
  * @brief  Nataveni priorit NVIC, nizsi cislo vyssi priorita
  * @param  : None
  * @retval : None
  */
void NVIC_my_config()	 //nested vector interrupt 
{	
	/* specifikace line prichoziho preruseni line 1 a 0, stanoveni jeho priority(0 az 3) */ 
	 NVIC_SetPriority(EXTI0_1_IRQn, 7);  // set priority for EXTIx
   NVIC_SetPriority(SysTick_IRQn,100); // set priority for systick
//	 NVIC_SetPriority(TIM2_IRQn,5);
// 	 NVIC_SetPriority(ADC1_COMP_IRQn,4);
//	 NVIC_SetPriority(DMA1_Channel1_IRQn,3);
	/* uvolneni preruseni z line 0 a 1 */
	NVIC_EnableIRQ(EXTI0_1_IRQn); // EXTI od PA0 tlacitka
	
  /* Enable the TIM2 global Interrupt */
  NVIC_EnableIRQ(TIM2_IRQn); // handler se musi jmenovat stejne 
}
	
