/*
*	Datalogger
* Program byl napsan pro mikrokontroler ARM Cortex STM32F051R8
*	Program umoznuje vzorkovani vstupu ADC prevodniku na pinu PA4, interval vzorkovani muze byt nastaven v radu
* us, ms, s a hodin. Dataloger muze ulozit max. 6000 udaju rozliseni pevne 8 bitu. 
* Nactena data mohou byt odeslana pomoci USART do PC parametry nastaveni 9600Baud, data 8bit, stop bit 1, parita ne.
* Pro sledovani prubehu lze pouzit software NRM_Display autora Ing. Ondej Pribula, K13138, CTU Prague
* Nastavovani pomoci trech tlacitek na pinech PA0 proti +3 V, PA1,2 proti GND.
* Zobrazovani LCD displejem 2x16znaku pripojeni na port B, definice pinu v souboru "stm32f0xx_LCD.h"
* Autor: Pavel Novotn
*	Date:  12/2012
* Licence: freeware
*/


#include "system_stm32f0xx.h"
#include "stm32f0xx_my_config.h"
#include "stm32f0xx_gpio.h"
#include "stm32f0xx_rcc.h"
#include "core_cm0.h"
#include "stm32f0xx_LCD.h"
#include "obsluha_rozhrani_HMI.h"
#include "main.h"
#include "stdint.h"
#include "stm32f0xx_adc.h"

/* Types define----------------------------------------------------------------*/


/* Private variables ---------------------------------------------------------*/
uint32_t ADC_value;  								//promenna ulozeni hodnoty ADC
static __IO uint32_t TimingDelay;		//pro zpozdeni pocita preruseni realizovane SYSTICK
extern uint8_t refresh_LCD;					//zadost o prekresleni LCD 
uint8_t storage[6000];							//definice a alokace pole uloziste vzorku

/* funkcni prototypy-----------------------------------------------------------*/
void delay(int);

/**
  * @brief  Nastaveni periferi, smycka DDS generatoru
  * @param  None
  * @retval None
  */
int main (void)
{ 	
	GPIO_my_config();						// volani nastaveni periferie obecnych vstupu vystupu
	EXTI_my_config();  					// volani nastaveni externiho preruseni pri stisku tlacitka na PA0
	SYSTICK_my_config(); 				// volani nastaveni periferie SYSTICK
	USART_my_config(); 					// volani nastaveni periferie USART
  DMA_my_config(1024);
	ADC_my_config();
	TIMER_my_config();
	NVIC_my_config();		 				// volani nastaveni preruseni
	LCD_my_config();						// volani funkce inicializujici display
	
	LCD_Clear();								// smazani LCD displaye
	set_cursor(0,0);	 				  // nastavi pozici cursoru LCD na (sloupec, radek)
		printLCD("   Datalogger   ");
	set_cursor(0,1);
		printLCD("Stiskni  tl. SET");
	

	/************************************************Zapis dat********************************************************/
	while(1)
	{	// realizace Datalogger
		if(refresh_LCD)
		{
			zobraz_data_signal();  	// obnoveni dat na displeji pri mereni
			refresh_LCD=0;       		// nastaveni priznaku display byl prekreslen
		}
	}
} // end of main()

/**
  * @brief  Cteni dat z registru ADC prevodniku
  * @param  : None
  * @retval : hodnota registru ADC_DR
  */
uint16_t ADC1_Read(void)
{
  // Wait until conversion completion
	//while(ADC_GetFlagStatus(ADC1, ADC_FLAG_EOSEQ) == RESET);
  // Get the conversion value
  return ADC_GetConversionValue(ADC1);
}

/**
  * @brief  Realizuje zpozdeni, kvantum je dane SYSTICK nastavene na 1ms
  * @param  : nTime hodnota casu pro zpozdeni
  * @retval : none
  */
void Delay(__IO uint32_t nTime)
{ 
  TimingDelay = nTime;
  while(TimingDelay != 0);   
}

void TimingDelay_Decrement(void)  // volana periodicky z obsluhy preruseni systick povolene pouze pri preruseni EXTI
{	
  if (TimingDelay != 0x00)
  { 
    TimingDelay--;
  }
}

 
